@@ -6,3 +6,7 @@
 #'
 #' @export
 match_arg <- strex::match_arg
+
+#' @rdname match_arg
+#' @export
+str_match_arg <- match_arg
