@@ -6,3 +6,7 @@
 #'
 #' @export
 str_to_vec <- strex::str_to_vec
+
+#' @rdname str_to_vec
+#' @export
+to_vec <- str_to_vec
